/******************************************************************************
 * File       : Gpio.c
 * Description: The routine mentioned  in this file initializes the  Port pins as outpins.
 *				Different functions are used to  control  LEDs

 * Copyright 2004 ZiLOG Inc.  ALL RIGHTS RESERVED.

 * The source code in this file was written by an
 * authorized ZiLOG employee or a licensed consultant.
 * The source code has been verified to the fullest
 * extent possible.
 * Permission to use this code is granted on a royalty-free
 * basis. However users are cautioned to authenticate the
 * code contained herein.
 * ZiLOG DOES NOT GUARANTEE THE VERACITY OF THE SOFTWARE.
 ************************************************************************/
#include<ez8.h>

#define DATA_DIRECTION 01


void init_gpio(void);
void turn_off__all_led(void);
void turn_on_all_led(void);
void normal_rangeLED_on(void);
void high_limitLED_on(void);  
void low_limitLED_on(void);

/*********************************************************************************
This function initializes Port A pins PA6 and PA7 as out put to control the 
LEDs D2, D3 respectively, on the target board. Also initializes port C pin PC3 
to control D4 on the target board.All these port pins are configured as output ports.
*********************************************************************************/


void init_gpio(void)
{

  PAADDR 	= DATA_DIRECTION;        // PA Data Dir =
  PACTL 	&= 0x3F;   				 // PA6-PA7 as Output

  PCADDR 	= DATA_DIRECTION;       // PC Data Dir
  PCCTL		&= 0xF7;			    // PC3 as Output

  LEDEN		= 0x08;					// PC3 uses LED drive
  LEDLVLH   = 0x08;					// PC3 Led Driver current = 7ma
  LEDLVLL   = 0x00;
  PAOUT |= 0xC0;  // Turn off PA6-PA7  leds
  PCOUT |= 0x08;	// Turn off PC3 Led
  
}


/***************************************************************************
This routiune turns off ALL LEDs
***************************************************************************/

void turn_off__all_led(void)
{
	PAOUT |= 0xC0;  // Turn off PA6-PA7  leds
  	PCOUT |= 0x08;	// Turn off PC3 Led
}

void turn_on_all_led(void)
{
  PAOUT &= 0x3F;  	    // Turn on PA6-PA7  leds
  PCOUT &= 0xF7;	    // Turn on PC3 Led
}

void normal_rangeLED_on(void)   // LED D3 is ON on the target board.
{
 
 PCOUT |= 0x08;	    // Turn off D4 LED (PORT PC3)
 PAOUT |= 0x70;     // Turn off D2 LED (PORT PA6)
 PAOUT &= 0x7F;  	// Turn on  D3 LED (PORT PA7)
}

void high_limitLED_on(void)   //LED D4 is ON on the target board
{
  PCOUT &= 0xF7;	    // Turn on D4 LED (PORT PC3)
  PAOUT |= 0xC0;        // Turn off D2 and D3 LED (PORT ,PA6 - PA7)
}


void low_limitLED_on(void)    //LED D2 is ON on the target board
{
  	PCOUT |= 0x08;	  // Turn off D4 LED (PORT PC3)
    PAOUT |= 0x80;    // Turn off D2 LED (PORT PA6)
    PAOUT &= 0xBF;    // Turn on  D3 LED (PORT PA7)
}



