/*************************************************************************
 * File       : timer.c
 * Description: Initializes the timer0 to contineous mode. The  Timer ISR 
 *				keeps track of the time in seconds and minutes.

 * Copyright 2004 ZiLOG Inc.  ALL RIGHTS RESERVED.

 * The source code in this file was written by an
 * authorized ZiLOG employee or a licensed consultant.
 * The source code has been verified to the fullest
 * extent possible.
 * Permission to use this code is granted on a royalty-free
 * basis. However users are cautioned to authenticate the
 * code contained herein.
 * ZiLOG DOES NOT GUARANTEE THE VERACITY OF THE SOFTWARE.
 ************************************************************************/

#include <eZ8.h>
#include "main.h"
#include "timer.h"
#include "uart.h"



unsigned char seconds = 0;				//Seconds counter
unsigned char minutes = 0;				//Minutes counter
unsigned char t_print_time=0;           //Half hour counter
unsigned char print_all_data = NO;			//Variable , to decide to send the data on  Serial port at 
								//every 30 minutes.
unsigned char store_data =NO;				//Variable, to decide, either to store data on NVDS or not
unsigned char print_every_minute =NO ;	



//Interrupt routine

#pragma interrupt
void isr_timer0(void) 
{
   
	DI();
	 seconds++;
	if(seconds >= SECONDS_COUNT)	// Increment the seconds counter
		{							//If seconds equal to or greater than  60
			seconds = 0;			//Increment the minute counter
			minutes++;
 			t_print_time++;
			print_every_minute = YES;
		}
	else if( minutes >= MINUTES_COUNT ) 			//Store data to NVDS area every five minutes
		{
			minutes = 0;		   
			store_data = YES;		                //Set the store flag
		}
    else if(t_print_time >= HALF_HOUR_COUNT)		//Print  all the stored data at every 30 minutes
		{
		   t_print_time = 0;
		   print_all_data = YES;
		}
	EI();

	
}

//**************************************************************************************
 //The timer0 is initialzed to generate an interrupt at every second.
//*************************************************************************************
void init_timer0(void)
{
	SET_VECTOR(TIMER0, isr_timer0); 
 	T0H		= (char)(TIMER_START_VALUE >> 0x08);// Timer High	
	T0L 	= (char)(TIMER_START_VALUE & 0xff);	// Timer Low

	T0RH 	=(char)(RELOADVALUE >> 0x08);		// Reload Compare High
	T0RL 	=(char)(RELOADVALUE & 0xff);	// Reload Compare Low

	T0CTL =  0xC1;			// Contineous mode 
	T0CTL |= SET_PRESCALE;	// pre scale of 128,

	IRQ0ENH |= 0x20;	// Set Interrupt Priority Nominal 
	IRQ0ENL &= 0xDF;	// Set Interrupt Priority Nominal
}

